@@ -26,7 +26,8 @@ class Package(object):
                 self.package_name,
                 self.package_folder,
                 template=self.get_template(),
-                name=['README.md', 'setup.cfg']
+                # name=['README.md', 'setup.cfg']
+                extensions=['py','md', 'cfg'] # Fix for python 3.6.9
             )
 
         except ModuleNotFoundError as e:
