@@ -86,7 +86,7 @@ class Project(object):
 
         try:
             # install djangoldp (and gets the right version of django as dependency)
-            cmd = ['pip', 'install', '--upgrade', '--no-cache', 'djangoldp']
+            cmd = ['pip', 'install', '--upgrade', '--no-cache', 'djangoldp<=2.0']
             if not self.is_venv():
                 cmd.append('--user')
             subprocess.run(cmd).check_returncode()
